# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 邮箱通知封装
# @Time   : 2022-11-04 22:05
# @Author : 毛鹏
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from socket import gaierror

from ..exceptions import MangoToolsError
from ..exceptions.error_msg import ERROR_MSG_0016
from ..models import EmailNoticeModel, TestReportModel


class EmailSend:

    def __init__(self, notice_config: EmailNoticeModel, test_report: TestReportModel = None, domain_name: str = None,
                 content: str = None):
        self.test_report = test_report
        self.notice_config = notice_config
        self.domain_name = domain_name
        self.content = content

    def send_main(self) -> None:
        if self.content is None:
            lines = [
                "       【芒果测试平台测试报告通知】"
            ]
            if self.test_report.project_name and self.test_report.product_name:
                lines.append(
                    f"                     项目产品：{self.test_report.project_name}/{self.test_report.product_name}")
            lines.append(f"                     测试环境：【{self.test_report.test_environment}】")
            if self.test_report.test_suite_id and self.test_report.task_name:
                lines.append(f"              测试套ID：【{self.test_report.test_suite_id}")
                lines.append(f"              任务名称：【{self.test_report.task_name}")
            lines.append(f"       *******************测试结果*******************")
            lines.extend([
                f"                     执行用例数：{self.test_report.case_sum}",
                f"                     通过用例数：{self.test_report.success}",
                f"                     失败用例数：{self.test_report.fail}",
                f"                     成  功  率：{self.test_report.success_rate}%"
            ])

            # 接口相关统计
            if self.test_report.api_case_sum is not None:
                lines.append(f"                     接口用例数：{self.test_report.api_case_sum}")
            if self.test_report.api_fail is not None:
                lines.append(f"                     接口失败数：{self.test_report.api_fail}")
            if self.test_report.api_call is not None:
                lines.append(f"                     接口调用数：{self.test_report.api_call}")

            # 前端相关统计
            if self.test_report.ui_case_sum is not None:
                lines.append(f"                     前端用例数：{self.test_report.ui_case_sum}")
            if self.test_report.ui_fail is not None:
                lines.append(f"                     前端失败数：{self.test_report.ui_fail}")
            if self.test_report.ui_step_call is not None:
                lines.append(f"                     前端步骤数：{self.test_report.ui_step_call}")

            # 单元测试相关统计
            if self.test_report.pytest_case_sum is not None:
                lines.append(f"                     单元用例数：{self.test_report.pytest_case_sum}")
            if self.test_report.pytest_fail is not None:
                lines.append(f"                     单元失败数：{self.test_report.pytest_fail}")
            if self.test_report.pytest_func_call is not None:
                lines.append(f"                     单元函数数：{self.test_report.pytest_func_call}")

            # 执行信息
            lines.extend([
                f"                     用例执行耗时：{self.test_report.execution_duration}",
                f"                     测试开始时间：{self.test_report.test_time}",
                "",
                "**************************************************************************"
            ])

            # 平台地址
            if self.domain_name:
                lines.append(f"      芒果自动化平台地址：{self.domain_name}")

            lines.append("      详细情况可前往芒果自动化平台查看，非相关负责人员可忽略此消息。谢谢！")

            # 将所有行连接成最终的邮件内容
            content = "\n".join(lines)
        else:
            content = self.content
        self.send_mail(self.notice_config.send_list, f'【芒果测试平台通知】', content)

    def send_mail(self, user_list: list, sub: str, content: str, ) -> None:
        try:
            user = f"MangoTestPlatform <{self.notice_config.send_user}>"
            msg = MIMEMultipart()
            msg['From'] = user
            msg['To'] = ";".join(user_list)
            msg['Subject'] = sub
            msg.attach(MIMEText(content, 'plain'))
            with smtplib.SMTP(self.notice_config.email_host, ) as server:
                server.starttls()
                server.login(self.notice_config.send_user, self.notice_config.stamp_key)
                server.sendmail(user, user_list, msg.as_string())
                server.quit()
        except (gaierror, smtplib.SMTPServerDisconnected):
            raise MangoToolsError(*ERROR_MSG_0016)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-07 23:25
# @Author : 毛鹏
from urllib.parse import unquote

encoded_str = "%E9%99%88%E6%A2%A6-%E5%B0%8F%E9%9F%B3%E7%AC%A6%2B%E8%9D%B4%E8%9D%B6%E9%9F%B3%E7%AC%A6"
decoded_str = unquote(encoded_str)
print(decoded_str)  # 输出：陈梦-小音符+蝴蝶音符


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-08-30 14:14
# @Author : 毛鹏
import base64
import json


class CodingTool:
    """编码"""

    @classmethod
    def base64_encode(cls, data: str) -> str:
        """编码字符串"""
        return base64.b64encode(json.dumps(data).encode('utf-8')).decode('utf-8')

    @classmethod
    def response_decoding(cls, data) -> str:
        """解码字符串"""
        return data.encode('latin-1').decode('unicode_escape').encode('utf-8', 'ignore').decode('utf-8')



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-03-07 8:24
# @Author : 毛鹏
import re

from ..data_processor._cache_tool import CacheTool
from ..data_processor._coding_tool import CodingTool
from ..data_processor._encryption_tool import EncryptionTool
from ..data_processor._json_tool import JsonTool
from ..data_processor._random_character_info_data import RandomCharacterInfoData
from ..data_processor._random_number_data import RandomNumberData
from ..data_processor._random_string_data import RandomStringData
from ..data_processor._random_time_data import RandomTimeData
from ..data_processor._sql_cache import SqlCache
from ..exceptions import MangoToolsError
from ..exceptions.error_msg import ERROR_MSG_0047, ERROR_MSG_0002
from ..mangos import Mango

"""
ObtainRandomData类的函数注释必须是： “”“中间写值”“”
"""


class ObtainRandomData(RandomNumberData, RandomCharacterInfoData, RandomTimeData, RandomStringData):
    """ 获取随机数据 """

    def regular(self, func: str):
        try:
            return Mango.regular(self, func)
        except AttributeError:
            raise MangoToolsError(*ERROR_MSG_0047)


class DataClean(JsonTool, CacheTool, EncryptionTool, CodingTool):
    """存储或处理随机数据"""
    pass


class DataProcessor(ObtainRandomData, DataClean):

    def __init__(self):
        ObtainRandomData.__init__(self)
        DataClean.__init__(self)

    def replace(self, data: list | dict | str | None) -> list | dict | str | None:
        if not data:
            return data
        if isinstance(data, list):
            return [self.replace(item) for item in data]
        elif isinstance(data, dict):
            return {key: self.replace(value) for key, value in data.items()}
        else:
            return Mango.replace_str(self, data, ERROR_MSG_0002, MangoToolsError)

    @classmethod
    def remove_parentheses(cls, data: str) -> str:
        return data.replace("${{", "").replace("}}", "").strip()

    @classmethod
    def identify_parentheses(cls, value: str):
        return re.search(r'\((.*?)\)', str(value))

    @classmethod
    def is_extract(cls, string: str) -> bool:
        return bool(re.search(r'\$\{\{.*\}\}', string))


__all__ = [
    'CacheTool',
    'CodingTool',
    'EncryptionTool',
    'JsonTool',
    'RandomCharacterInfoData',
    'RandomNumberData',
    'RandomStringData',
    'RandomTimeData',
    'ObtainRandomData',
    'DataClean',
    'DataProcessor',
    'SqlCache'
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-24 10:01
# @Author : 毛鹏

from mangotools.mangos import Mango, get, test

Mango.v(1, '测试通过')
print(type(get))

test(1, data=1)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-28 14:38
# @Author : 毛鹏
import unittest


from mangotools.data_processor import ObtainRandomData


class TestCacheTool(unittest.TestCase):
    def setUp(self):
        """在每个测试方法前初始化"""
        self.random = ObtainRandomData()

    def test_basic_operations(self):
        """测试基本缓存操作"""
        # 测试设置和获取缓存
        print(self.random.regular('randint(left=2,right=5)'))
        print(self.random.regular('number_random_hex_str(digits=8)'))
        print(self.random.regular('number_random_bin_str()'))

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:09
# @Author : 毛鹏
from mangotools.assertion.sql._sql import MysqlAssertion


class SqlAssertion(MysqlAssertion):
    """SQL断言"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-07 22:15
# @Author : 毛鹏
import sys

python_version = sys.version_info

if "3.1" not in f"{python_version.major}.{python_version.minor}":
    raise Exception("必须使用>Python3.10.4")
